pub struct MmapBackend { /* private fields */ }Expand description
Memory-mapped I/O backend for zero-copy operations.
Implementations
Sourceimpl MmapBackend
impl MmapBackend
Sourcepub fn read(&self, offset: usize, buf: &mut [u8]) -> Result<usize, Error>
pub fn read(&self, offset: usize, buf: &mut [u8]) -> Result<usize, Error>
Reads data at the given offset.
Sourcepub fn write(&self, offset: usize, buf: &[u8]) -> Result<usize, Error>
pub fn write(&self, offset: usize, buf: &[u8]) -> Result<usize, Error>
Writes data at the given offset.
Sourcepub const unsafe fn as_ptr(&self) -> *const u8
pub const unsafe fn as_ptr(&self) -> *const u8
Returns a pointer to the mapped memory.
Safety
The caller must ensure the pointer is used within the valid range.
Sourcepub const unsafe fn as_mut_ptr(&self) -> *mut u8
pub const unsafe fn as_mut_ptr(&self) -> *mut u8
Returns a mutable pointer to the mapped memory.
Safety
The caller must ensure the pointer is used within the valid range and the backend is not read-only.