pub struct PtyConsole { /* private fields */ }Expand description
PTY (pseudo-terminal) console backend.
Provides a real terminal interface that can be connected to by terminal emulators or the host shell.
Implementations
Sourceimpl PtyConsole
impl PtyConsole
Sourcepub fn new() -> Result<PtyConsole, Error>
pub fn new() -> Result<PtyConsole, Error>
Sourcepub fn slave_path(&self) -> &str
pub fn slave_path(&self) -> &str
Returns the path to the slave PTY device.
Users can connect to this path with a terminal emulator:
screen /dev/pts/Xminicom -D /dev/pts/X